pilas.motores.motor_qt.SonidoDeshabilitado

Package pilas :: Package motores :: Module motor_qt :: Class SonidoDeshabilitado |
[hide private]
[frames] | no frames]

# Class SonidoDeshabilitado

source code

Instance Methods | [hide private]
__init__(self, player, ruta) | source code
reproducir(self) | source code
detener(self) | source code
pausar(self) | source code
continuar(self) | source code

Class Variables | [hide private]
| deshabilitado = `True`